@@ -1,5 +1,9 @@
 """A base class for widgets that show information about the source."""
 
+##############################################################################
+# Backward compatibility.
+from __future__ import annotations
+
 ##############################################################################
 # Python imports.
 import ast
